@@ -911,34 +911,6 @@ sub setProperties {
 }
 
 
-sub generateFacets {
-    my $this = shift();
-    my($records) = @_;
-    my $admin = $this->admin();
-
-    my $facet;
-    if ($admin->configValue("showFacets")) {
-	require 'Masterkey/Admin/Facets.pm';
-	$facet = Masterkey::Admin::Facets->new_group( 'facets' => ["categories", "serviceProvider", "opacVendor", "displayName"], 'max' => 5, 'uri' => ".");
-
-	foreach my $i (1 .. scalar(@$records)) {
-	    my $rec = $records->[$i-1];
-
-	    $facet->{"serviceProvider"}->add($rec->field( "serviceProvider" ));
-	    $facet->{"opacVendor"}->add($rec->field( "opacVendor" ));
-	    $facet->{"displayName"}->add($rec->field( "displayName" ))
-		if $admin->configValue("showTagCloud");
-	    if ($rec->field("categories")) {
-		foreach my $cat (split /[,,]/, $rec->field("categories")) {
-		    $facet->{"categories"}->add($cat);
-		}
-	    }
-	}
-    }
-
-    return $facet;
-}
-
 sub sortedRecords {
     my $this = shift();
     return $this->_sortedList(0, @_);
@@ -965,7 +937,8 @@ sub _sortedList {
     $query .= " sortby displayName/sort.ignoreCase";
 
     my @facetNames;
-    push @facetNames, 'categories:\054', 'serviceProvider', 'opacVendor'
+    # The odd "categories:\054" tells the Torus to split the categories field on commas.
+    push @facetNames, 'categories:\054', 'serviceProvider', 'opacVendor', 'openAccess'
 	if $this->admin()->configValue("showFacets");
     push @facetNames, "displayName"
 	if $this->admin()->configValue("showTagCloud");
